﻿using Electric.Domain.Entities.Identity;
using Electric.Domain.Manager.Identity;

using Microsoft.AspNetCore.Identity;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.DependencyInjection.Extensions;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Electric.Domain.DependencyInjection
{
    public static class ServiceCollectionExtensions
    {
        /// <summary>
        /// 领域注入
        /// </summary>
        /// <param name="services"></param>
        public static void AddDomain(this IServiceCollection services)
        {
            //注入UserManager
            services.TryAddScoped(typeof(UserManager));
#pragma warning disable CS8603 // 可能返回 null 引用。
            services.TryAddScoped(typeof(UserManager<EleUser>), provider => provider.GetService(typeof(UserManager)));
#pragma warning restore CS8603 // 可能返回 null 引用。

            //注入UserStore
            services.TryAddScoped(typeof(UserStore));
#pragma warning disable CS8603 // 可能返回 null 引用。
            services.TryAddScoped(typeof(IUserStore<EleUser>), provider => provider.GetService(typeof(UserStore)));
#pragma warning restore CS8603 // 可能返回 null 引用。

            //注入RoleManager
            services.TryAddScoped<RoleManager>();
#pragma warning disable CS8603 // 可能返回 null 引用。
            services.TryAddScoped(typeof(RoleManager<EleRole>), provider => provider.GetService(typeof(RoleManager)));
#pragma warning restore CS8603 // 可能返回 null 引用。

            //注入RoleStore
            services.TryAddScoped<RoleStore>();
#pragma warning disable CS8603 // 可能返回 null 引用。
            services.TryAddScoped(typeof(IRoleStore<EleRole>), provider => provider.GetService(typeof(RoleStore)));
#pragma warning restore CS8603 // 可能返回 null 引用。

            //配置Identity的用户类型和角色
            services.AddIdentityCore<EleUser>().AddRoles<EleRole>().AddUserStore<UserStore>()
                .AddRoleStore<RoleStore>();
        }
    }
}